#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tz
version:              0.1.3.6
visibility:           public
id:                   tz-0.1.3.6-BxqHH40itjJ5yNmp0RRsr4
key:                  tz-0.1.3.6-BxqHH40itjJ5yNmp0RRsr4
license:              Apache-2.0
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Mihaly Barasz, Gergely Risko
stability:            experimental
homepage:             https://github.com/ysangkok/haskell-tz
synopsis:             Efficient time zone handling
description:
    The goal of this package is to provide a library that can read time
    zone info files (aka. Olson files), and does time zone conversions
    in a /pure/ and /efficient/ way.

    We also provide platform-independent and/or compiled-in access to
    the standard Time Zone Dabase by the means of the companion @tzdata@
    package <http://hackage.haskell.org/package/tzdata>.

    The package is currently in an alpha phase, I'\''m still experimenting
    with different ideas wrt. scope\/API\/implementation\/etc. All
    comments are welcome!

category:             Data
abi:                  2ed14a756898707b4ea2ab93034e91bf
exposed:              True
exposed-modules:
    Data.Time.Zones Data.Time.Zones.All Data.Time.Zones.Internal
    Data.Time.Zones.Read Data.Time.Zones.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tz-0.1.3.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tz-0.1.3.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tz-0.1.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tz
hs-libraries:         HStz-0.1.3.6-BxqHH40itjJ5yNmp0RRsr4
depends:
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    time-1.12.2 tzdata-0.2.20250115.0-CPvcH0RFHcz2bmq6L2nJXm
    vector-0.13.2.0-KxN9ggrWD4mCYNpXRxsIZo

haddock-interfaces:   /usr/share/doc/haskell-tz/html/tz.haddock
haddock-html:         /usr/share/doc/haskell-tz/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

